@@ -7,9 +7,12 @@ import os
 from os import path
 import pkgutil
 
+import beancount
 import fava
 
-MODULES = list(pkgutil.walk_packages(fava.__path__, fava.__name__ + "."))
+MODULES = list(
+    pkgutil.walk_packages(fava.__path__, fava.__name__ + ".")
+) + list(pkgutil.walk_packages(beancount.__path__, beancount.__name__ + "."))
 
 RST_PATH = path.join(path.dirname(__file__), "api")
 if not path.isdir(RST_PATH):
@@ -21,12 +24,15 @@ def heading(name, level="-"):
     return f"{name}\n{level * len(name)}\n\n"
 
 
-for package in ["fava"] + [mod.name for mod in MODULES if mod.ispkg]:
+for package in ["fava", "beancount"] + [
+    mod.name for mod in MODULES if mod.ispkg
+]:
     submodules = [
         mod.name
         for mod in MODULES
         if mod.name.startswith(package)
         and not mod.ispkg
+        and "_test" not in mod.name
         and mod.name.count(".") == package.count(".") + 1
     ]
     with open(path.join(RST_PATH, f"{package}.rst"), "w") as rst:
