@@ -18,6 +18,7 @@ from beancount.core.data import (
     Balance,
     TxnPosting,
     Transaction,
+    Document,
     Event,
     Custom,
 )
@@ -390,6 +391,11 @@ class FavaLedger:
             ) in realization.iterate_with_balance(postings)
         ]
 
+    @property
+    def documents(self):
+        """All currently filtered documents."""
+        return list(filter_type(self.entries, Document))
+
     def events(self, event_type=None):
         """List events (possibly filtered by type)."""
         events = filter_type(self.entries, Event)
