@@ -1,19 +1,46 @@
 """Ingest helper functions."""
 
-import operator
-import os
-from os import path
-import runpy
 from collections import namedtuple
+import datetime
+from os import path
+import os
+import runpy
 import sys
 import traceback
 
-from beancount.ingest import cache, identify, extract
+from beancount.ingest import cache
+from beancount.ingest import extract
+from beancount.ingest import identify
 
 from fava.core.helpers import FavaModule
 
 IngestError = namedtuple("IngestError", "source message entry")
 
+FileImporters = namedtuple("FileImporters", "name basename importers")
+FileImportInfo = namedtuple(
+    "FileImportInfo", "importer_name account date name"
+)
+
+
+def file_import_info(filename: str, importer) -> FileImportInfo:
+    """Generate info about a file with an importer."""
+    # pylint: disable=broad-except
+    file = cache.get_file(filename)
+    try:
+        account = importer.file_account(file)
+    except Exception:
+        account = ""
+    try:
+        date = importer.file_date(file)
+    except Exception:
+        date = datetime.date.today()
+    try:
+        name = importer.file_name(file)
+    except Exception:
+        name = path.basename(filename)
+
+    return FileImportInfo(importer.name(), account, date, name)
+
 
 class IngestModule(FavaModule):
     """Exposes ingest functionality."""
@@ -27,14 +54,10 @@ class IngestModule(FavaModule):
     @property
     def module_path(self):
         """The path to the importer configuration."""
-        if not self.ledger.fava_options["import-config"]:
+        config_path = self.ledger.fava_options["import-config"]
+        if not config_path:
             return None
-        return path.normpath(
-            path.join(
-                path.dirname(self.ledger.beancount_file_path),
-                self.ledger.fava_options["import-config"],
-            )
-        )
+        return self.ledger.join_path(config_path)
 
     def load_file(self):
         if not self.ledger.fava_options["import-config"]:
@@ -74,26 +97,30 @@ class IngestModule(FavaModule):
             importer.name(): importer for importer in self.config
         }
 
-    def identify_directory(self, directory):
-        """Identify files and importers for a given directory.
-
-        Args:
-            directory: The directory to search (relative to Beancount file).
+    def import_data(self):
+        """Identify files and importers that can be imported.
 
         Returns:
-            Tuples of filenames and lists of matching importers.
+            A dict mapping directories to lists of :class:`.FileImportInfo`.
         """
         if not self.config:
-            return []
+            return {}
 
-        full_path = path.normpath(
-            path.join(path.dirname(self.ledger.beancount_file_path), directory)
-        )
+        ret = {}
 
-        return filter(
-            operator.itemgetter(1),
-            identify.find_imports(self.config, full_path),
-        )
+        for directory in self.ledger.fava_options["import-dirs"]:
+            full_path = self.ledger.join_path(directory)
+            files = list(identify.find_imports(self.config, full_path))
+            ret[directory] = []
+            for (filename, importers) in files:
+                basename = path.basename(filename)
+                infos = [
+                    file_import_info(filename, importer)
+                    for importer in importers
+                ]
+                ret[directory].append(FileImporters(filename, basename, infos))
+
+        return ret
 
     def extract(self, filename, importer_name):
         """Extract entries from filename with the specified importer.
@@ -117,39 +144,8 @@ class IngestModule(FavaModule):
             existing_entries=self.ledger.all_entries,
         )
 
-        if isinstance(new_entries, tuple):
-            new_entries, _ = new_entries
+        new_entries = extract.find_duplicate_entries(
+            [(filename, new_entries)], self.ledger.all_entries
+        )[0][1]
 
         return new_entries
-
-    @staticmethod
-    def file_account(filename, importer):
-        """Account for the given file.
-
-        Args:
-            filename: The full path to a file.
-            importer: An importer that matched the file.
-
-        Returns:
-            The account name or the exception message if one occurs.
-        """
-        try:
-            return importer.file_account(cache.get_file(filename))
-        except Exception as exception:  # pylint: disable=broad-except
-            return str(exception)
-
-    @staticmethod
-    def file_date(filename, importer):
-        """Date for the given file.
-
-        Args:
-            filename: The full path to a file.
-            importer: An importer that matched the file.
-
-        Returns:
-            The date or the exception message if one occurs.
-        """
-        try:
-            return importer.file_date(cache.get_file(filename))
-        except Exception as exception:  # pylint: disable=broad-except
-            return str(exception)
