@@ -6,6 +6,7 @@ from beancount.core import account, convert
 from beancount.core.data import Open
 
 from fava.core.inventory import CounterInventory
+from fava.template_filters import cost_or_value
 
 
 class TreeNode:
@@ -25,6 +26,20 @@ class TreeNode:
         #: bool: True if the account has any transactions.
         self.has_txns = False
 
+    def serialise(self, end):
+        """Serialise the account.
+
+        Args:
+            end: A date to use for cost conversions.
+        """
+        children = [child.serialise(end) for child in self.children]
+        return {
+            "account": self.name,
+            "balance_children": cost_or_value(self.balance_children, end),
+            "balance": cost_or_value(self.balance, end),
+            "children": children,
+        }
+
 
 class Tree(dict):
     """Account tree.
@@ -98,6 +113,24 @@ class Tree(dict):
                 self[name] = node
             return node
 
+    def net_profit(self, options, account_name):
+        """Calculate the net profit.
+
+        Args:
+            options: The Beancount options.
+            account_name: The name to use for the account containing the net
+                profit.
+        """
+        income = self.get(options["name_income"])
+        expenses = self.get(options["name_expenses"])
+
+        net_profit = Tree()
+        net_profit.insert(
+            account_name, income.balance_children + expenses.balance_children
+        )
+
+        return net_profit.get(account_name)
+
     def cap(self, options, unrealized_account):
         """Transfer Income and Expenses, add conversions and unrealized gains.
 
