@@ -1,13 +1,13 @@
 """Some small utility functions."""
-
 import functools
 import itertools
 import logging
 import os
 import re
-import unicodedata
 import time
+import unicodedata
 
+from flask import abort
 from flask import send_file
 from werkzeug.urls import url_quote
 
@@ -16,10 +16,10 @@ BASEPATH = os.path.realpath(os.path.join(os.path.dirname(__file__), ".."))
 
 def filter_api_changed(record):
     """Filter out LogRecords for requests that poll for changes."""
-    return not record.msg.endswith('api/changed/ HTTP/1.1" 200 -')
+    return "/api/changed/" not in record.msg
 
 
-def setup_logging():
+def setup_logging() -> None:
     """Setup logging for Fava."""
     logging.basicConfig(level=logging.INFO, format="%(message)s")
     logging.getLogger("werkzeug").addFilter(filter_api_changed)
@@ -91,7 +91,10 @@ def send_file_inline(filename):
 
     Ref: http://test.greenbytes.de/tech/tc2231/.
     """
-    response = send_file(filename)
+    try:
+        response = send_file(filename)
+    except FileNotFoundError:
+        return abort(404)
     basename = os.path.basename(filename)
     cont_disp = "inline; filename*=UTF-8''{}".format(url_quote(basename))
     response.headers["Content-Disposition"] = cont_disp
